#!/usr/bin/perl -w

###############################################################################
# vmmap.pl
#
# Use mminfo to work out the saveset name/NetWorker VM ID for a virtual machine
# based on its hostname. This script is provided by Preston de Guise from the
# NetWorker Blog with no warranty.
###############################################################################


###############################################################################
# Modules
###############################################################################
use strict;
use Getopt::Std;
use File::Basename;

###############################################################################
# Variables
###############################################################################
my $self = basename($0);
my %opts = ();
my $version = "1.0";
my $client = "";

###############################################################################
# Subroutines
###############################################################################
sub usage {
	print <<EOF;
Syntax:

$self [-h] [-v] -c client

	-h		Print this help and exit
	-v		Print version and exit
	-c client	Lookup NetWorker VM ID for specified client.

EOF

	if (@_+0 != 0) {
		my @messages = @_;
		my $message;
		foreach my $message (@messages) {
			my $tmp = $message;
			chomp $tmp;
			print "$tmp\n";
		}
	}
	die "\n";
}

sub find_client {
	return 0 if (@_+0 != 1);

	my $client = $_[0];
	if (open(MMI,"mminfo -k -q \"vmname=$client,savetime>=1 month ago\" -r savetime,name -xc, -otR |")) { 
		# Read past header
		my $line = <MMI>;
		# Read what we need
		$line = <MMI>;
		chomp $line;
		close (MMI);
		my $fullID = (split(/\,/,$line))[1];
		my $vmID = (split(/:/,$fullID))[1];
		print "vm:" . $vmID . "\n";
	} else {
		die "Unable to run mminfo\n";
	}
}

###############################################################################
# Main
###############################################################################

if (getopts('hvc:',\%opts)) {
	die("$self is v$version\n") if (defined($opts{v}));
	usage() if (defined($opts{h}));

	if (defined($opts{c})) {
		$client = $opts{c};
	} else {
		usage("You must supply a client to find.");
	}
}

find_client ($client);
